..
    This file is part of Invenio.
    Copyright (C) 2015-2024 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.0.4 (released 2024-01-28)

- Allow table HTML tags for sanitization

Version 1.0.3 (released 2020-05-06)

- Deprecated Python versions lower than 3.6.0. Now supporting 3.6.0 and 3.7.0.

Version 1.0.2 (released 2019-07-29)

- Added `ALLOWED_HTML_TAGS` and `ALLOWED_HTML_ATTRS` config keys.

Version 1.0.1 (released 2018-10-02)

- Application configurations are now sorted and loaded in alphabetical order.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
